<?php
/**
 * Plugin Name: Food Online for WooCommerce
 * Plugin URI: https://wordpress.org/plugins/food-online-for-woocommerce/
 * Description: A restaurant ordering system for WooCommerce.
 * Version: 2.1.0
 * Author: Arosoft.se
 * Author URI: https://arosoft.se
 * Developer: Arosoft.se
 * Developer URI: https://arosoft.se
 * Text Domain: fdoe
 * Domain Path: /languages
 * Copyright: Arosoft.se 2018
 * License: GPL v2 or later
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */
define( 'FOOD_ONLINE_VERSION', '2.1.0' );
if ( !defined( 'ABSPATH' ) ) {
    exit;
}
/*
 *Classes{

	Food_Online_
	Food_Online_Ajax_
	Food_Online_Del_
	Food_Online_Settings_
	Food_Online_Product_
	Food_Online_Loop_

 }
 *
 */
register_activation_hook( __FILE__, array(
     'Food_Online',
    'activate'
) );
register_uninstall_hook( __FILE__, array(
     'Food_Online',
    'uninstall'
) );
if ( !class_exists( 'Food_Online' ) ) {
    /**
		 * Main Class Food_Online
		 *
		 * @since 1.0
		 */
    class Food_Online
    {
        const TEXT_DOMAIN = 'fdoe';
		 // to be run on plugin activation
        static function activate()
        {

            update_option( 'Food_Online_Activated_Plugin', 'Food_Online' );
            add_option( 'fdoe_override_guests', 'no' );
			add_option('fdoe_menu_titles_icon', 'fas fa-ellipsis-h');
			add_option('fdoe_color', '#bf5bb6');
			add_option('fdoe_item_icon', 'fas fa-plus-circle');
			add_option('fdoe_show_images', 'rec');
			add_option('fdoe_popup_image', 'no');
			add_option('fdoe_popup_meta', 'no');
			add_option('fdoe_disable_bootstrap', 'no');
			add_option('fdoe_popup_meta', 'no');
			update_option('fdoe_layout', 'fdoe_onecol');
			add_option('fdoe_hide_minicart', 'no');
			update_option('fdoe_is_prem', 'no');
		}
         // to be run on plugin uninstallation
         public static function uninstall()
        {

            delete_option('fdoe_override_guests');
			delete_option('fdoe_menu_titles_icon');
			delete_option('fdoe_color');
			delete_option('fdoe_item_icon');
			delete_option('fdoe_show_images');
			delete_option('fdoe_popup_image');
			delete_option('fdoe_popup_meta');
			delete_option('fdoe_disable_bootstrap');
			delete_option('fdoe_popup_meta');
			delete_option('fdoe_layout');
			delete_option('fdoe_hide_minicart');
			delete_option('fdoe_is_prem');
        }
        protected static $_instance = null;
        public $override_templates = false;
        public $product;
        public $loop;
        public $notices;
        protected $settings;

		public static $categories_raw;

         // sets $categories to product categories
        public static function set_categories()
        {
            $taxonomy         = 'product_cat';
            $orderby          = 'name';
            $show_count       = 0; // 1 for yes, 0 for no
            $pad_counts       = 0; // 1 for yes, 0 for no
            $hierarchical     = 1; // 1 for yes, 0 for no
            $title            = '';
            $empty            = 0;
            $args             = array(
                 'taxonomy' => $taxonomy,
                'orderby' => $orderby,
                'show_count' => $show_count,
                'pad_counts' => $pad_counts,
                'hierarchical' => $hierarchical,
                'title_li' => $title,
                'hide_empty' => $empty
            );
            self::$categories_raw = get_categories( $args );

        }

        // Return product categories
        public static function get_categories_raw()
        {
            return self::$categories_raw;
        }
        // The Constructor
        public function __construct()
        {
            add_action( 'admin_init', array(
                 $this,
                'check_environment'
            ) );
            add_action( 'admin_notices', array(
                 $this,
                'admin_notices'
            ), 15 );
            add_action( 'plugins_loaded', array(
                 $this,
                'init'
            ), 10 );
            add_action( 'init', array(
                 $this,
                'load_text_domain'
            ) );



        }
        // Enqueues admin scripts and styles
        public function enqueue_scripts_back_end()
        {
          if ( isset ($_GET['tab']) && $_GET['tab'] === 'fdoe' ) {
            wp_enqueue_style( 'wp-color-picker' );
            wp_enqueue_script( 'fdoe-admin-script-handle', $this->get_plugin_url( 'assets/js/fdoe-order-admin.js' ), array(
                 'wp-color-picker',
                'jquery'
            ), false, true );


			wp_enqueue_style( 'fdoe-admin-style', $this->get_plugin_url( 'assets/css/admin-style.css' ) );
			wp_enqueue_style( 'fdoe-order-font-3', $this->get_plugin_url( 'assets/fontawesome/css/fontawesome.min.css' ) );
				wp_enqueue_style( 'fdoe-order-font-4', $this->get_plugin_url( 'assets/fontawesome/css/solid.min.css' ) );
        }
		}
        // Includes plugin files
        public function includes()
        {
        include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
            // For support of WooCommerce Add-On
          if (  is_plugin_active('woocommerce-product-addons/woocommerce-product-addons.php')) {
            include_once( ABSPATH . 'wp-content/plugins/woocommerce-product-addons/includes/class-product-addon-display.php' );
          }
            require_once( 'classes/class-fdoe-product.php' );
            require_once( 'classes/class-fdoe-loop.php' );
			require_once( 'classes/class-fdoe-ajax.php' );


		// Check if to run the premium version
		update_option('fdoe_is_prem', 'no');

		if( file_exists(plugin_dir_path(__FILE__) . 'prem') ){

			        require_once( 'prem/class-fdoe-del.php' );
					require_once( 'prem/class-fdoe-settings-prem.php' );
					update_option('fdoe_is_prem', 'yes');
			}
			else{
				 require_once( 'classes/class-fdoe-settings.php' );

			}
        }
        // Returns new class instance
        public static function instance()
        {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }
            return self::$_instance;
        }
       // Plugin initiation
        public function init()
        {
		// For support of WooCommerce Add-On
			add_action( 'wp_loaded',  function(){
			 if (  is_plugin_active('woocommerce-product-addons/woocommerce-product-addons.php')) {
				 remove_all_actions( 'woocommerce_before_variations_form', 10 );
				}
			});
            // check if environment is ok
            if ( self::get_environment_warning() ) {
                return;
            }
            if ( is_admin() && get_option( 'Food_Online_Activated_Plugin' ) == 'Food_Online' ) {
                delete_option( 'Food_Online_Activated_Plugin' );
            }
            $this->includes();
			remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );
            remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs', 10 );
            remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
            remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
            remove_action( 'woocommerce_review_before', 'woocommerce_review_display_gravatar', 10 );
            remove_action( 'woocommerce_review_before_comment_meta', 'woocommerce_review_display_rating', 10 );
            remove_action( 'woocommerce_review_comment_text', 'woocommerce_review_display_comment_text', 10 );
            remove_action( 'woocommerce_product_thumbnails', 'woocommerce_show_product_thumbnails', 20 );
            remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_sale_flash', 10 );
             if ( WC_Admin_Settings::get_option('fdoe_popup_image') == 'no' ){
            remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_images', 20 );
             }
            if ( WC_Admin_Settings::get_option('fdoe_popup_meta') == 'no' ){
            remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );
            }
            remove_action( 'woocommerce_after_single_product_summary', 'storefront_upsell_display', 15 );
            remove_action( 'woocommerce_after_single_product_summary', 'storefront_single_product_pagination', 40 );

            add_action( 'wp_enqueue_scripts', array(
                 $this,
                'load_bootstrap_and_fontawesome'
            ),10);




            add_action( 'wp_enqueue_scripts', array(
                 $this,
                'enqueue_scripts'
            ) );
            add_action( 'woocommerce_init', array(
                 $this,
                'woocommerce_init'
            ) );
            add_action( 'wp_footer', array(
                 $this,
                'load_templates'
            ) );

			add_action( 'wp_footer', array(
                 $this,
                'fdoe_output_cart_modal'
            ) );


            add_action( 'template_redirect', array(
                 $this,
                'check_for_404'
            ) );
            add_action( 'wp', array(
                 $this,
                'wp'
            ) );
            add_action( 'admin_enqueue_scripts', array(
                 $this,
                'enqueue_scripts_back_end'
            ) );
            add_filter( 'woocommerce_show_page_title', '__return_false' );
            add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), array(
                $this,
                'add_action_links'
            ) );

			add_action( 'woocommerce_widget_shopping_cart_buttons', function()
{
    // Removing Buttons
    remove_action( 'woocommerce_widget_shopping_cart_buttons', 'woocommerce_widget_shopping_cart_button_view_cart', 10 );
    remove_action( 'woocommerce_widget_shopping_cart_buttons', 'woocommerce_widget_shopping_cart_proceed_to_checkout', 20 );
    // Adding customized Buttons
    add_action( 'woocommerce_widget_shopping_cart_buttons',array($this, 'fdoe_custom_widget_shopping_cart_proceed_to_checkout'), 20 );
}, 1 );



			add_action( 'init', array($this, 'fdoe_storefront_sorting_remove' ) );

			add_filter( 'add_to_cart_fragments', array($this,'fdoe_woocommerce_header_add_to_cart_fragment') );


			$theme = wp_get_theme(); // gets the current theme
if (  !('Storefront' == $theme->name || 'Storefront' == $theme->parent_theme )) {
 add_action( 'wp_footer', array($this, 'fdoe_handheld_footer_bar'),  999 );

}else{

			add_filter( 'storefront_handheld_footer_bar_links', array($this,'fdoe_add_checkout_link_2') );
			add_filter( 'storefront_handheld_footer_bar_links', array($this,'fdoe_add_shop_link') );
			add_filter( 'storefront_handheld_footer_bar_links', array($this,'fdoe_add_cart_link') );
			add_filter( 'storefront_handheld_footer_bar_links', array($this,'fdoe_remove_handheld_footer_links') );
			set_theme_mod( 'storefront_product_pagination', false );

}
        }
        // Checks if environment is ok
        public function check_environment()
        {
            if ( is_admin() && get_option( 'Food_Online_Activated_Plugin' ) == 'Food_Online' ) {
                delete_option( 'Food_Online_Activated_Plugin' );
            }
            $environment_warning = self::get_environment_warning();
            if ( $environment_warning && is_plugin_active( plugin_basename( __FILE__ ) ) ) {
              $this->add_admin_notice( 'bad_environment', 'error', $environment_warning );
                deactivate_plugins( plugin_basename( __FILE__ ) );
            }
        }

		// Output the mini cart in an modal for handheld devices
	public function fdoe_output_cart_modal()
{
    echo '  <div class="modal cart-modal fdoe-modal fade" id="cart_modal"  tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true" style="display:none">
            <div class="modal-dialog modal-sm" role="document">
            <div class="modal-content">
            <div class="modal-header">
            <h5 class="modal-title" id="exampleModalLabel_cart">' . esc_html__( 'Your Order', Food_Online::TEXT_DOMAIN ) . '</h5>
            </div>
            <div class="modal-body" >
            <div class="container">
			 <div class="row">
			<div class="col-xs-10 fdoe-minicart-main-column ">
            <div class="fdoe_mini_cart_2" id="fdoe_mini_cart_id_2" style="display:inline">
            ';
    woocommerce_mini_cart();
    echo '  </div>
            </div>
            </div>
            <div class="modal-footer" id="mini_cart_modal_footer" >
            <div class="container">
			 <div class="col-xs-10 fdoe-minicart-main-column">
			  <div class="row">
            <button type="button" class="button" data-dismiss="modal">' . esc_html__( 'Close', Food_Online::TEXT_DOMAIN ) . '</button>
            </div>
			</div>
			 </div>
			</div>
            </div>
			</div>
            </div>
            </div>
            </div>
            </div>
            </div>
            ';
}



		public function output_product_modals()
		{

/*
			?> <div class="modal product-modal fdoe-modal fade" style="display:none" id="myModal_" tabindex="-1" role="dialog" aria-labelledby="productModalLabel_"


 aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="productModalLabel_"></h5> <button type="button" class="close" data-dismiss="modal" aria-label=" <?php
            echo __( 'Close', Food_Online::TEXT_DOMAIN );
?>">
          <span aria-hidden="true">&times;</span>
        </button> </div>
                <div class="modal-body">
					<div class="container-flud">
						<div class="row">
								<div class="col-xs-12">
                    <?php
           // echo do_shortcode( $fdoe_shortcode );
?> </div>
								</div>
				</div>
						</div>
                <div class="modal-footer"> <button type="button" class="button" data-dismiss="modal"><?php
            echo __( 'Close', Food_Online::TEXT_DOMAIN );
?></button>

				</div>
            </div>
        </div>
    </div> <?php


*/


           	$cats_to_include = get_option('fdoe_category_order');

	  if ( get_option('fdoe_is_prem') == 'yes' && is_array($cats_to_include)){

			$cats = array_column($cats_to_include,'ID');
			 $fdoe_params = array(
			'posts_per_page' => 999,
			'post_status' => 'publish',
			'post_type' => 'product',
			'tax_query' => array(
				 array(
						'taxonomy' => 'product_cat',
						'field' => 'term_id',
						 'terms' => $cats,
						 'operator' => 'IN'
					)
									 ));

			}else{

			$fdoe_params = array(
			'posts_per_page' => 999,
			'post_status' => 'publish',
			'post_type' => 'product',
			);

				}
$wc_query    = new WP_Query( $fdoe_params );
if ( $wc_query->have_posts() ):
    // Loops through the products and creates it´s products modals
    while ( $wc_query->have_posts() ):
        $wc_query->the_post();
        if ( get_post_type() == 'product' ) {
            $fdoe_itemid    = get_the_ID();
            $fdoe_shortcode = '[product_page id="' . $fdoe_itemid . '" ]';
?>
   <div class="modal product-modal fdoe-modal fade" style="display:none" id="myModal_<?php
            the_ID();
?>" tabindex="-1" role="dialog" aria-labelledby="productModalLabel_<?php
            the_ID();
?>"


 aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="productModalLabel_<?php
            the_ID();
?>"></h5> <button type="button" class="close" data-dismiss="modal" aria-label=" <?php
            echo __( 'Close', Food_Online::TEXT_DOMAIN );
?>">
          <span aria-hidden="true">&times;</span>
        </button> </div>
                <div class="modal-body">
					<div class="container-flud">
						<div class="row">
								<div class="col-xs-12">
                    <?php
            echo do_shortcode( $fdoe_shortcode );
?> </div>
								</div>
				</div>
						</div>
                <div class="modal-footer"> <button type="button" class="button" data-dismiss="modal"><?php
            echo __( 'Close', Food_Online::TEXT_DOMAIN );
?></button>

				</div>
            </div>
        </div>
    </div>
    <?php
        }
    endwhile;
    wp_reset_postdata();
else:
    wp_reset_postdata();
endif;
        }
        // Checks if WooCommerce is active and if not returns error message
         static function get_environment_warning()
        {
			include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

            if ( !defined( 'WC_VERSION' ) ) {


                return __( 'Food Online requires WooCommerce to be activated to work.', Food_Online::TEXT_DOMAIN );

                die();
            }
			//if this is Premium
/*
			else if ( is_plugin_active( 'food-online-for-woocommerce/fdoe-order.php') ) {


                return __( 'Food Online Premium can not be activated when the free version is active.', Food_Online::TEXT_DOMAIN );
                die();
            }*/
			// If this is free version
			else if ( is_plugin_active( 'food-online-premium/fdoe-order.php') ) {
                return __( 'Food Online can not be activated when the premuim version is active.', Food_Online::TEXT_DOMAIN );
                die();
            }
            return false;
        }





        public function add_admin_notice( $slug, $class, $message )
        {
            $this->notices[ $slug ] = array(
                 'class' => $class,
                'message' => $message
            );
        }
        public function admin_notices()
        {
            foreach ( (array) $this->notices as $notice_key => $notice ) {
                echo "<div class='" . esc_attr( $notice[ 'class' ] ) . "'><p>";
                echo wp_kses( $notice[ 'message' ], array(
                     'a' => array(
                         'href' => array ()
                    )
                ) );
                echo '</p></div>';
            }
            unset( $notice_key );
        }
       // Make sure to override only at shop and at category archive
        public function wp()
        {
            if ( is_product_category() || is_shop() ){

			add_action( 'wp_footer', array(
                 $this,
                'output_product_modals'
            ) );

                return;
			}
            $this->override_off();
        }
        // Add setting link to Plugins page
        public function add_action_links( $links )
        {

			 if(get_option('fdoe_is_prem') == 'no'){
            $links_add = array(
                 '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=fdoe&section' ) . '">Settings</a>',

				 '<a href="http://foodonlineplugin.com">Go Premium</a>',
            );
			}
			else{

				 $links_add = array(
                 '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=layout&section' ) . '">Settings</a>');

			}
            return array_merge( $links, $links_add);
        }
        // Loads the product template to override with
        public function load_templates()
        {
            include( 'templates/product.php' );
        }
        // Enqueues scripts and styles front end
        public function enqueue_scripts()
        {
            if ( WP_DEBUG === true ) {
                wp_enqueue_style( 'fdoe-order', $this->get_plugin_url( 'assets/css/style.css' ) );
                wp_enqueue_script( 'fdoe-order', $this->get_plugin_url( 'assets/js/fdoe-order.js' ), array(
                     'jquery',
                    'backbone'
                ), FOOD_ONLINE_VERSION, true );
            } else {
                wp_enqueue_style( 'fdoe-order', $this->get_plugin_url( 'assets/css/style.min.css' ) );
                wp_enqueue_script( 'fdoe-order', $this->get_plugin_url( 'assets/js/fdoe-order.min.js' ), array(
                     'jquery',
                    'backbone'
                ), FOOD_ONLINE_VERSION, true );



            }



            global $wp_query;
            self::set_categories();
            $theme = wp_get_theme();
            // Checks if Storefront is active and gets itÂ´s colors
            if ( 'Storefront' == $theme->name || 'Storefront' == $theme->parent_theme ) {
                $themecol      = get_theme_mod( 'storefront_header_link_color' );
                $themecol_text = get_theme_mod( 'storefront_header_background_color' );
            } else {
                $themecol      = '';
                $themecol_text = '';
            }
            $menu_color = WC_Admin_Settings::get_option( 'fdoe_color' );
            $args       = array(
				'fdoe_item_separator' => get_option('fdoe_item_separator'),
                'is_checkout' => is_checkout(),
                'menu_color' => $menu_color,
                'footer_text_color' => $themecol_text,
                'footer_heading_color' => $themecol,
                'fdoe_popup_image' => WC_Admin_Settings::get_option('fdoe_popup_image'),
                'fdoe_show_images' => WC_Admin_Settings::get_option( 'fdoe_show_images' ),
                'cats' => self::get_categories_raw(),
                'base_path' => get_option( 'siteurl' ),
                'cart_remove_url' => wc_get_cart_remove_url( 'fdoe_item_key' ),
                'wc_ajax_url' => WC_AJAX::get_endpoint( '%%endpoint%%' ),
				'layout' => WC_Admin_Settings::get_option('fdoe_layout'),
				'hide_minicart' => WC_Admin_Settings::get_option('fdoe_hide_minicart'),
				'ajax_url' => admin_url( 'admin-ajax.php' ),
				'theme' => $theme->name,
				'theme_parent' => $theme->parent_theme,
				'fdoe_show_images' => get_option( 'fdoe_show_images' )

            );
            wp_localize_script( 'fdoe-order', 'fdoe', $args );
        }


		public function load_bootstrap_and_fontawesome(){

		if ( WC_Admin_Settings::get_option('fdoe_disable_bootstrap') != 'yes' ){



		wp_enqueue_style( 'fdoe-order-boot-css', $this->get_plugin_url( 'assets/bootstrap/css/bootstrap.min.css' ) );
        wp_enqueue_script( 'fdoe-order-boot-js', $this->get_plugin_url( 'assets/bootstrap/js/bootstrap.min.js' ));

 }



			 	wp_enqueue_style( 'fdoe-order-font-1', $this->get_plugin_url( 'assets/fontawesome/css/fontawesome.min.css' ) );
				wp_enqueue_style( 'fdoe-order-font-2', $this->get_plugin_url( 'assets/fontawesome/css/solid.min.css' ) );


		}


        // Override theme default specification for product # per row
        public function change_loop_columns()
        {
            return 999;
        }
        public function woocommerce_init()
        {
            if ( is_user_logged_in() || WC_Admin_Settings::get_option( 'fdoe_override_guests' ) === 'yes' ) {
                $this->override_on();

		add_filter( 'loop_shop_per_page', function($cols){

			// Return the number of products you wanna show per page.
			 $cols = 50;
			 return $cols;



			}, 20 );


                add_filter( 'loop_shop_columns', array(
                     $this,
                    'change_loop_columns'
                ), 999 );
                add_filter( 'storefront_loop_columns', array(
                     $this,
                    'change_loop_columns'
                ), 999 );
            }
            $this->product = new Food_Online_Product();
			$this->ajax = new Food_Online_Ajax();
            $this->loop    = new Food_Online_Loop( $this->product );
        }




        // For use in future versions. Loads text domain files
        public function load_text_domain()
        {
            load_plugin_textdomain( Food_Online::TEXT_DOMAIN, false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

        }
        // Disables the template override if 404 eror
        public function check_for_404()
        {
            if ( is_404() )
                $this->override_off();
        }
        // Turns on template overriding
        public function override_on()
        {
            add_filter( 'woocommerce_locate_template', array(
                 $this,
                'override_templates'
            ), 20, 3 );
            add_filter( 'wc_get_template_part', array(
                 $this,
                'override_template_part'
            ), 10, 3 );

			add_filter( 'wc_get_template', array($this, 'override_cart_template'), 99, 5 );

        }
	public function override_cart_template( $located, $template_name, $args, $template_path, $default_path ) {
    if ( 'cart/mini-cart.php' == $template_name ) {
        $located = plugin_dir_path( __FILE__ ) . 'templates/fdoe-cart/mini-cart.php';
    }

    return $located;
}
        // Turns off template overriding
        public function override_off()
        {
            remove_filter( 'woocommerce_locate_template', array(
                 $this,
                'override_templates'
            ) );
            remove_filter( 'wc_get_template_part', array(
                 $this,
                'override_template_part'
            ) );
			remove_filter( 'wc_get_template', array($this, 'override_cart_template') );
        }
        // Gets path to templates
        public function get_template_path( $relativePath = '' )
        {
            return $this->base_path( '/templates/' . WC()->template_path() . $relativePath );
        }
        // Gets the base path
        protected function base_path( $relativePath = '' )
        {
            $rc = new \ReflectionClass( get_class( $this ) );
            return dirname( $rc->getFileName() ) . $relativePath;
        }
        // Performs the template overriding
         function override_templates( $template, $template_name, $template_path )
        {
            global $woocommerce;
            $_template = $template;
            if ( !$template_path ) {
                $template_path = $woocommerce->template_url;
            }
            $plugin_path = $this->get_template_path();


            if ( file_exists( $plugin_path . $template_name ) ) {
                $template = $plugin_path . $template_name;
            }
            if ( !$template ) {
                $template = locate_template( array(
                     $template_path . $template_name,
                    $template_name
                ) );
            }
            if ( !$template ) {
                $template = $_template;
            }
            return $template;
        }
        // Gets the url to the plugin
        protected function get_plugin_url( $relativePath = '' )
        {
            return untrailingslashit( plugins_url( $relativePath, $this->base_path_file() ) );
        }
        // Gets the class filenamne
        protected function base_path_file()
        {
            $rc = new \ReflectionClass( get_class( $this ) );
            return $rc->getFileName();
        }
        public function override_template_part( $template, $slug, $name )
        {
            if ( $name ) {
                $path = $this->get_template_path( "{$slug}-{$name}.php" );
            } else {
                $path = $this->get_template_path( "{$slug}.php" );
            }
            return file_exists( $path ) ? $path : $template;
        }


		// Adds new checkout button
 public function fdoe_custom_widget_shopping_cart_proceed_to_checkout()
{
    $original_link = wc_get_checkout_url();
    echo '<a href="' . esc_url( $original_link ) . '" class="button checkout from_menu" id="checkout_button_1">' . esc_html__( 'Go to Checkout', Food_Online::TEXT_DOMAIN ) . '</a>';
}
// Adds checkout button in the handheld footer bar for Storefront Theme

public function fdoe_add_checkout_link_2( $links )
{
	 function fdoe_checkout_link_2()
{
    if ( is_product_category() || is_shop() ) {
        echo '<a class="checkout from_menu" id="checkout_button_11" href="' . esc_url( wc_get_checkout_url() ) . '" >';
        echo ' <span class="fdoe_checkout_22">' . esc_html__( 'Checkout', Food_Online::TEXT_DOMAIN ) . '</span> ';
        echo '</a>';
    }
}

    $new_links = array(
         'fdoe_checkout_2' => array(
             'priority' => 8,
             'callback' => 'fdoe_checkout_link_2'
        )
    );
    $links     = array_merge( $new_links, $links );
    return $links;
}


public function fdoe_add_shop_link( $links )
{
	 function fdoe_shop_link()
{
    echo '<a href="' . esc_url( get_permalink( wc_get_page_id( 'shop' ) ) ) . '"></a>';
}
    $new_links = array(
         'shop' => array(
             'priority' => 10,
            'callback' => 'fdoe_shop_link'
        )
    );
    $links     = array_merge( $new_links, $links );
    return $links;
}


public function fdoe_add_cart_link( $links )
{
	// Creates cart links for handheld devices in Storefront footer bar
 function fdoe_cart_link()
{
    if ( is_product_category() || is_shop() ) {
        $count = WC()->cart->cart_contents_count;
        echo ' <a  id="cart_modal_link" data-toggle="modal" data-target="#cart_modal" href="" title="">';
        echo ' <span class="fdoe_count">' . esc_html( $count ) . '</span> ';
        echo ' </a>';
    } else {
        $count = WC()->cart->cart_contents_count;
        echo '<a href="' . esc_url( get_permalink( wc_get_page_id( 'cart' ) ) ) . '">' ;
        echo ' <span class="fdoe_count">' . esc_html( $count ) . '</span>';
        echo ' </a>';
    }
}

    $new_links = array(
         'minicart' => array(
             'priority' => 10,
             'callback' => 'fdoe_cart_link'
        )
    );
    $links     = array_merge( $new_links, $links );
    return $links;
}

	/**
	 * Display a menu intended for use on handheld devices, inspired of Storefront
	 *
	 *
	 */
	public function fdoe_handheld_footer_bar() {



		 function fdoe_checkout_link_2()
{
    if ( is_product_category() || is_shop() ) {
        echo '<a class="checkout from_menu" id="checkout_button_11" href="' . esc_url( wc_get_checkout_url() ) . '" >';
        echo ' <span class="fdoe_checkout_22">' . esc_html__( 'Checkout', Food_Online::TEXT_DOMAIN ) . '</span> ';
        echo '</a>';
    }
}

 function fdoe_cart_link()
{


    if ( is_product_category() || is_shop() ) {
        $count = WC()->cart->cart_contents_count;
        echo ' <a  id="cart_modal_link" data-toggle="modal" data-target="#cart_modal" href="" title="">';
        echo ' <span class="fdoe_count">' . esc_html( $count ) . '</span> ';
        echo ' </a>';
    } else {
        $count = WC()->cart->cart_contents_count;
        echo '<a href="' . esc_url( get_permalink( wc_get_page_id( 'cart' ) ) ) . '">' ;
        echo ' <span class="fdoe_count">' . esc_html( $count ) . '</span> ';
        echo ' </a>';
    }
}

 function fdoe_shop_link()
{
    echo '<a href="' . esc_url( get_permalink( wc_get_page_id( 'shop' ) ) ) . '"></a>';
}

		$links = array(
            'minicart' => array(
			'priority' => 8,
			'callback' => 'fdoe_cart_link',
		),
			'shop' => array(
			'priority' => 10,
			'callback' => 'fdoe_shop_link',
		),
            'fdoe_checkout_2' => array(
			'priority' => 12,
			'callback' => 'fdoe_checkout_link_2',
		),
		);
		?>
<div class="fdoe-handheld-footer-bar">
	<ul class="columns-<?php echo count( $links ); ?>">
		<?php foreach ( $links as $key => $link ) : ?>
		<li class="<?php echo esc_attr( $key ); ?>">
			<?php
						if ( $link['callback'] ) {
							call_user_func( $link['callback'], $key, $link );
						}
						?> </li>
		<?php endforeach; ?> </ul>
</div>
<?php
	}
	// Updates the items count in Storefront footer bar

public function fdoe_woocommerce_header_add_to_cart_fragment( $fragments )
{
    global $woocommerce;
    ob_start();
?> <span class="fdoe_count"><?php echo $woocommerce->cart->cart_contents_count; ?>
 </span>
<?php
  $fragments[ 'span.fdoe_count' ] = ob_get_clean();
    return $fragments;
}
//Removes links from Storefront handheld footer bar

public function fdoe_remove_handheld_footer_links( $links )
{
    unset( $links[ 'my-account' ] );
    unset( $links[ 'search' ] );
    unset( $links[ 'cart' ] );
    return $links;
}

//Removes Storefront sorting option

public function fdoe_storefront_sorting_remove()
{
    remove_action( 'woocommerce_after_shop_loop', 'woocommerce_catalog_ordering', 10 );
    remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 10 );
}



    } // End of main class
}
$GLOBALS[ 'wc_list_items' ] = Food_Online::instance();

// Mini cart adjustments

add_filter( 'wc_add_to_cart_message_html', '__return_false' );
